# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x11org.couchers.auth\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x9d\x02\n\rSignupFlowReq\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12-\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x1e.org.couchers.auth.SignupBasic\x12\x31\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32 .org.couchers.auth.SignupAccount\x12\x34\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\x12\x19\n\x0b\x65mail_token\x18\x05 \x01(\tB\x04\x80\xb5\x18\x01\x12?\n\x1b\x61\x63\x63\x65pt_community_guidelines\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xdd\x01\n\rSignupFlowRes\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12,\n\x08\x61uth_res\x18\x03 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\x12\x12\n\nneed_basic\x18\x04 \x01(\x08\x12\x14\n\x0cneed_account\x18\x05 \x01(\x08\x12\x15\n\rneed_feedback\x18\x06 \x01(\x08\x12\x19\n\x11need_verify_email\x18\x07 \x01(\x08\x12(\n need_accept_community_guidelines\x18\x08 \x01(\x08\"*\n\x0bSignupBasic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"0\n\x12SignupTokenInfoReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"\xe6\x01\n\rSignupAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x01\x12\x0b\n\x03lng\x18\x08 \x01(\x01\x12\x0e\n\x06radius\x18\t \x01(\x01\x12\x11\n\tbirthdate\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12<\n\x0ehosting_status\x18\x05 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12\x12\n\naccept_tos\x18\n \x01(\x08\"$\n\x10UsernameValidReq\x12\x10\n\x08username\x18\x01 \x01(\t\"!\n\x10UsernameValidRes\x12\r\n\x05valid\x18\x01 \x01(\x08\"\x18\n\x08LoginReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"z\n\x08LoginRes\x12\x38\n\tnext_step\x18\x01 \x01(\x0e\x32%.org.couchers.auth.LoginRes.LoginStep\"4\n\tLoginStep\x12\x11\n\rNEED_PASSWORD\x10\x00\x12\x14\n\x10SENT_LOGIN_EMAIL\x10\x01\"2\n\x15\x43ompleteTokenLoginReq\x12\x19\n\x0blogin_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"H\n\x07\x41uthReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x17\n\x0fremember_device\x18\x03 \x01(\x08\"*\n\x07\x41uthRes\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0e\n\x06jailed\x18\x02 \x01(\x08\" \n\x10ResetPasswordReq\x12\x0c\n\x04user\x18\x01 \x01(\t\">\n\x18\x43ompletePasswordResetReq\x12\"\n\x14password_reset_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"9\n\x15\x43onfirmChangeEmailReq\x12 \n\x12\x63hange_email_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"Q\n\x15\x43onfirmChangeEmailRes\x12\x38\n\x05state\x18\x01 \x01(\x0e\x32).org.couchers.auth.EmailConfirmationState\"\xab\x01\n\x0f\x43ontributorForm\x12\r\n\x05ideas\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x01(\t\x12\x12\n\nexperience\x18\x03 \x01(\t\x12\x37\n\ncontribute\x18\x04 \x01(\x0e\x32#.org.couchers.auth.ContributeOption\x12\x17\n\x0f\x63ontribute_ways\x18\x05 \x03(\t\x12\x11\n\texpertise\x18\x06 \x01(\t\".\n\x17\x43onfirmDeleteAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"(\n\x11RecoverAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\".\n\x0eUnsubscribeReq\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\"\"\n\x0eUnsubscribeRes\x12\x10\n\x08response\x18\x01 \x01(\t*\xea\x01\n\x16\x45mailConfirmationState\x12$\n EMAIL_CONFIRMATION_STATE_UNKNOWN\x10\x00\x12$\n EMAIL_CONFIRMATION_STATE_SUCCESS\x10\x01\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL\x10\x02\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL\x10\x03*\x87\x01\n\x10\x43ontributeOption\x12!\n\x1d\x43ONTRIBUTE_OPTION_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43ONTRIBUTE_OPTION_YES\x10\x01\x12\x1b\n\x17\x43ONTRIBUTE_OPTION_MAYBE\x10\x02\x12\x18\n\x14\x43ONTRIBUTE_OPTION_NO\x10\x03\x32\xa8\x08\n\x04\x41uth\x12i\n\nSignupFlow\x12 .org.couchers.auth.SignupFlowReq\x1a .org.couchers.auth.SignupFlowRes\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/auth/signup:\x01*\x12[\n\rUsernameValid\x12#.org.couchers.auth.UsernameValidReq\x1a#.org.couchers.auth.UsernameValidRes\"\x00\x12\x43\n\x05Login\x12\x1b.org.couchers.auth.LoginReq\x1a\x1b.org.couchers.auth.LoginRes\"\x00\x12\\\n\x12\x43ompleteTokenLogin\x12(.org.couchers.auth.CompleteTokenLoginReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12H\n\x0c\x41uthenticate\x12\x1a.org.couchers.auth.AuthReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\x42\n\x0e\x44\x65\x61uthenticate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\rResetPassword\x12#.org.couchers.auth.ResetPasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x15\x43ompletePasswordReset\x12+.org.couchers.auth.CompletePasswordResetReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x12\x43onfirmChangeEmail\x12(.org.couchers.auth.ConfirmChangeEmailReq\x1a(.org.couchers.auth.ConfirmChangeEmailRes\"\x00\x12\\\n\x14\x43onfirmDeleteAccount\x12*.org.couchers.auth.ConfirmDeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x0eRecoverAccount\x12$.org.couchers.auth.RecoverAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\x0bUnsubscribe\x12!.org.couchers.auth.UnsubscribeReq\x1a!.org.couchers.auth.UnsubscribeRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._loaded_options = None
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._serialized_options = b'\200\265\030\001'
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._loaded_options = None
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_COMPLETETOKENLOGINREQ'].fields_by_name['login_token']._loaded_options = None
  _globals['_COMPLETETOKENLOGINREQ'].fields_by_name['login_token']._serialized_options = b'\200\265\030\001'
  _globals['_AUTHREQ'].fields_by_name['password']._loaded_options = None
  _globals['_AUTHREQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_COMPLETEPASSWORDRESETREQ'].fields_by_name['password_reset_token']._loaded_options = None
  _globals['_COMPLETEPASSWORDRESETREQ'].fields_by_name['password_reset_token']._serialized_options = b'\200\265\030\001'
  _globals['_CONFIRMCHANGEEMAILREQ'].fields_by_name['change_email_token']._loaded_options = None
  _globals['_CONFIRMCHANGEEMAILREQ'].fields_by_name['change_email_token']._serialized_options = b'\200\265\030\001'
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\200\265\030\001'
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\200\265\030\001'
  _globals['_AUTH']._loaded_options = None
  _globals['_AUTH']._serialized_options = b'\210\265\030\001'
  _globals['_AUTH'].methods_by_name['SignupFlow']._loaded_options = None
  _globals['_AUTH'].methods_by_name['SignupFlow']._serialized_options = b'\202\323\344\223\002\021\"\014/auth/signup:\001*'
  _globals['_EMAILCONFIRMATIONSTATE']._serialized_start=1975
  _globals['_EMAILCONFIRMATIONSTATE']._serialized_end=2209
  _globals['_CONTRIBUTEOPTION']._serialized_start=2212
  _globals['_CONTRIBUTEOPTION']._serialized_end=2347
  _globals['_SIGNUPFLOWREQ']._serialized_start=155
  _globals['_SIGNUPFLOWREQ']._serialized_end=440
  _globals['_SIGNUPFLOWRES']._serialized_start=443
  _globals['_SIGNUPFLOWRES']._serialized_end=664
  _globals['_SIGNUPBASIC']._serialized_start=666
  _globals['_SIGNUPBASIC']._serialized_end=708
  _globals['_SIGNUPTOKENINFOREQ']._serialized_start=710
  _globals['_SIGNUPTOKENINFOREQ']._serialized_end=758
  _globals['_SIGNUPACCOUNT']._serialized_start=761
  _globals['_SIGNUPACCOUNT']._serialized_end=991
  _globals['_USERNAMEVALIDREQ']._serialized_start=993
  _globals['_USERNAMEVALIDREQ']._serialized_end=1029
  _globals['_USERNAMEVALIDRES']._serialized_start=1031
  _globals['_USERNAMEVALIDRES']._serialized_end=1064
  _globals['_LOGINREQ']._serialized_start=1066
  _globals['_LOGINREQ']._serialized_end=1090
  _globals['_LOGINRES']._serialized_start=1092
  _globals['_LOGINRES']._serialized_end=1214
  _globals['_LOGINRES_LOGINSTEP']._serialized_start=1162
  _globals['_LOGINRES_LOGINSTEP']._serialized_end=1214
  _globals['_COMPLETETOKENLOGINREQ']._serialized_start=1216
  _globals['_COMPLETETOKENLOGINREQ']._serialized_end=1266
  _globals['_AUTHREQ']._serialized_start=1268
  _globals['_AUTHREQ']._serialized_end=1340
  _globals['_AUTHRES']._serialized_start=1342
  _globals['_AUTHRES']._serialized_end=1384
  _globals['_RESETPASSWORDREQ']._serialized_start=1386
  _globals['_RESETPASSWORDREQ']._serialized_end=1418
  _globals['_COMPLETEPASSWORDRESETREQ']._serialized_start=1420
  _globals['_COMPLETEPASSWORDRESETREQ']._serialized_end=1482
  _globals['_CONFIRMCHANGEEMAILREQ']._serialized_start=1484
  _globals['_CONFIRMCHANGEEMAILREQ']._serialized_end=1541
  _globals['_CONFIRMCHANGEEMAILRES']._serialized_start=1543
  _globals['_CONFIRMCHANGEEMAILRES']._serialized_end=1624
  _globals['_CONTRIBUTORFORM']._serialized_start=1627
  _globals['_CONTRIBUTORFORM']._serialized_end=1798
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_start=1800
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_end=1846
  _globals['_RECOVERACCOUNTREQ']._serialized_start=1848
  _globals['_RECOVERACCOUNTREQ']._serialized_end=1888
  _globals['_UNSUBSCRIBEREQ']._serialized_start=1890
  _globals['_UNSUBSCRIBEREQ']._serialized_end=1936
  _globals['_UNSUBSCRIBERES']._serialized_start=1938
  _globals['_UNSUBSCRIBERES']._serialized_end=1972
  _globals['_AUTH']._serialized_start=2350
  _globals['_AUTH']._serialized_end=3414
# @@protoc_insertion_point(module_scope)
