# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notifications.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13notifications.proto\x12\x1aorg.couchers.notifications\x1a\x11\x61nnotations.proto\"\x1c\n\x1aGetNotificationSettingsReq\"?\n\x1aGetNotificationSettingsRes\x12!\n\x19new_notifications_enabled\x18\x01 \x01(\x08\">\n\x1aSetNotificationSettingsReq\x12 \n\x18\x65nable_new_notifications\x18\x01 \x01(\x08\"\x1c\n\x1aSetNotificationSettingsRes2\xad\x02\n\rNotifications\x12\x89\x01\n\x17GetNotificationSettings\x12\x36.org.couchers.notifications.GetNotificationSettingsReq\x1a\x36.org.couchers.notifications.GetNotificationSettingsRes\x12\x89\x01\n\x17SetNotificationSettings\x12\x36.org.couchers.notifications.SetNotificationSettingsReq\x1a\x36.org.couchers.notifications.SetNotificationSettingsRes\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NOTIFICATIONS']._loaded_options = None
  _globals['_NOTIFICATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_start=70
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_end=98
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_start=100
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_end=163
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_start=165
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_end=227
  _globals['_SETNOTIFICATIONSETTINGSRES']._serialized_start=229
  _globals['_SETNOTIFICATIONSETTINGSRES']._serialized_end=257
  _globals['_NOTIFICATIONS']._serialized_start=260
  _globals['_NOTIFICATIONS']._serialized_end=561
# @@protoc_insertion_point(module_scope)
