# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stripe.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cstripe.proto\x12\x13org.couchers.stripe\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x11\x61nnotations.proto2^\n\x06Stripe\x12N\n\x07Webhook\x12\x14.google.api.HttpBody\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/stripe/webhook\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stripe_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STRIPE']._loaded_options = None
  _globals['_STRIPE']._serialized_options = b'\210\265\030\001'
  _globals['_STRIPE'].methods_by_name['Webhook']._loaded_options = None
  _globals['_STRIPE'].methods_by_name['Webhook']._serialized_options = b'\202\323\344\223\002\021\"\017/stripe/webhook'
  _globals['_STRIPE']._serialized_start=113
  _globals['_STRIPE']._serialized_end=207
# @@protoc_insertion_point(module_scope)
