# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pages.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bpages.proto\x12\x16org.couchers.api.pages\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"&\n\nCoordinate\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\"\xb0\x04\n\x04Page\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .org.couchers.api.pages.PageType\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_edited\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13last_editor_user_id\x18\x06 \x01(\x03\x12\x17\n\x0f\x63reator_user_id\x18\x07 \x01(\x03\x12\x17\n\rowner_user_id\x18\x08 \x01(\x03H\x00\x12\x1c\n\x12owner_community_id\x18\x11 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\t \x01(\x03H\x00\x12\x30\n\x06thread\x18\x14 \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\r\n\x05title\x18\x0b \x01(\t\x12\x0f\n\x07\x63ontent\x18\x0c \x01(\t\x12\x11\n\tphoto_url\x18\x13 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\r \x01(\t\x12\x34\n\x08location\x18\x0e \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\x12\x17\n\x0f\x65\x64itor_user_ids\x18\x0f \x03(\x03\x12\x10\n\x08\x63\x61n_edit\x18\x10 \x01(\x08\x12\x14\n\x0c\x63\x61n_moderate\x18\x12 \x01(\x08\x42\x07\n\x05owner\"\x8a\x01\n\x0e\x43reatePlaceReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x05 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x34\n\x08location\x18\x04 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"\xa7\x01\n\x0e\x43reateGuideReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x06 \x01(\t\x12\x1b\n\x13parent_community_id\x18\x03 \x01(\x03\x12\x0f\n\x07\x61\x64\x64ress\x18\x04 \x01(\t\x12\x34\n\x08location\x18\x05 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"\x1d\n\nGetPageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\"\x92\x02\n\rUpdatePageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12+\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tphoto_key\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x61\x64\x64ress\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x08location\x18\x05 \x01(\x0b\x32\".org.couchers.api.pages.Coordinate\"o\n\x0fTransferPageReq\x12\x0f\n\x07page_id\x18\x01 \x01(\x03\x12 \n\x16new_owner_community_id\x18\x03 \x01(\x03H\x00\x12\x1c\n\x12new_owner_group_id\x18\x02 \x01(\x03H\x00\x42\x0b\n\tnew_owner\"K\n\x11ListUserPlacesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Z\n\x11ListUserPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"K\n\x11ListUserGuidesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Z\n\x11ListUserGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*M\n\x08PageType\x12\x13\n\x0fPAGE_TYPE_PLACE\x10\x00\x12\x13\n\x0fPAGE_TYPE_GUIDE\x10\x01\x12\x17\n\x13PAGE_TYPE_MAIN_PAGE\x10\x02\x32\x8c\x05\n\x05Pages\x12U\n\x0b\x43reatePlace\x12&.org.couchers.api.pages.CreatePlaceReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12U\n\x0b\x43reateGuide\x12&.org.couchers.api.pages.CreateGuideReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12M\n\x07GetPage\x12\".org.couchers.api.pages.GetPageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12S\n\nUpdatePage\x12%.org.couchers.api.pages.UpdatePageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12W\n\x0cTransferPage\x12\'.org.couchers.api.pages.TransferPageReq\x1a\x1c.org.couchers.api.pages.Page\"\x00\x12h\n\x0eListUserPlaces\x12).org.couchers.api.pages.ListUserPlacesReq\x1a).org.couchers.api.pages.ListUserPlacesRes\"\x00\x12h\n\x0eListUserGuides\x12).org.couchers.api.pages.ListUserGuidesReq\x1a).org.couchers.api.pages.ListUserGuidesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PAGES']._loaded_options = None
  _globals['_PAGES']._serialized_options = b'\210\265\030\003'
  _globals['_PAGETYPE']._serialized_start=1811
  _globals['_PAGETYPE']._serialized_end=1888
  _globals['_COORDINATE']._serialized_start=138
  _globals['_COORDINATE']._serialized_end=176
  _globals['_PAGE']._serialized_start=179
  _globals['_PAGE']._serialized_end=739
  _globals['_CREATEPLACEREQ']._serialized_start=742
  _globals['_CREATEPLACEREQ']._serialized_end=880
  _globals['_CREATEGUIDEREQ']._serialized_start=883
  _globals['_CREATEGUIDEREQ']._serialized_end=1050
  _globals['_GETPAGEREQ']._serialized_start=1052
  _globals['_GETPAGEREQ']._serialized_end=1081
  _globals['_UPDATEPAGEREQ']._serialized_start=1084
  _globals['_UPDATEPAGEREQ']._serialized_end=1358
  _globals['_TRANSFERPAGEREQ']._serialized_start=1360
  _globals['_TRANSFERPAGEREQ']._serialized_end=1471
  _globals['_LISTUSERPLACESREQ']._serialized_start=1473
  _globals['_LISTUSERPLACESREQ']._serialized_end=1548
  _globals['_LISTUSERPLACESRES']._serialized_start=1550
  _globals['_LISTUSERPLACESRES']._serialized_end=1640
  _globals['_LISTUSERGUIDESREQ']._serialized_start=1642
  _globals['_LISTUSERGUIDESREQ']._serialized_end=1717
  _globals['_LISTUSERGUIDESRES']._serialized_start=1719
  _globals['_LISTUSERGUIDESRES']._serialized_end=1809
  _globals['_PAGES']._serialized_start=1891
  _globals['_PAGES']._serialized_end=2543
# @@protoc_insertion_point(module_scope)
