# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x12org.couchers.admin\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\"\x83\x01\n\x0bUserDetails\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12\x11\n\tbirthdate\x18\x07 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x05 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\"!\n\x11GetUserDetailsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"3\n\x13\x43hangeUserGenderReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06gender\x18\x02 \x01(\t\"9\n\x16\x43hangeUserBirthdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"\x1a\n\nBanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1d\n\rDeleteUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"%\n\x15RecoverDeletedUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0f\x43reateApiKeyReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x11\n\x0f\x43reateApiKeyRes\"\x81\x01\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t\"\x1b\n\x0bGetChatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0bGetChatsRes\x12\x10\n\x08response\x18\x02 \x01(\t2\xc7\x06\n\x05\x41\x64min\x12Z\n\x0eGetUserDetails\x12%.org.couchers.admin.GetUserDetailsReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12^\n\x10\x43hangeUserGender\x12\'.org.couchers.admin.ChangeUserGenderReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x64\n\x13\x43hangeUserBirthdate\x12*.org.couchers.admin.ChangeUserBirthdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12L\n\x07\x42\x61nUser\x12\x1e.org.couchers.admin.BanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nDeleteUser\x12!.org.couchers.admin.DeleteUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x62\n\x12RecoverDeletedUser\x12).org.couchers.admin.RecoverDeletedUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12Z\n\x0c\x43reateApiKey\x12#.org.couchers.admin.CreateApiKeyReq\x1a#.org.couchers.admin.CreateApiKeyRes\"\x00\x12\x64\n\x0f\x43reateCommunity\x12&.org.couchers.admin.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12N\n\x08GetChats\x12\x1f.org.couchers.admin.GetChatsReq\x1a\x1f.org.couchers.admin.GetChatsRes\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADMIN']._loaded_options = None
  _globals['_ADMIN']._serialized_options = b'\210\265\030\004'
  _globals['_USERDETAILS']._serialized_start=74
  _globals['_USERDETAILS']._serialized_end=205
  _globals['_GETUSERDETAILSREQ']._serialized_start=207
  _globals['_GETUSERDETAILSREQ']._serialized_end=240
  _globals['_CHANGEUSERGENDERREQ']._serialized_start=242
  _globals['_CHANGEUSERGENDERREQ']._serialized_end=293
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_start=295
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_end=352
  _globals['_BANUSERREQ']._serialized_start=354
  _globals['_BANUSERREQ']._serialized_end=380
  _globals['_DELETEUSERREQ']._serialized_start=382
  _globals['_DELETEUSERREQ']._serialized_end=411
  _globals['_RECOVERDELETEDUSERREQ']._serialized_start=413
  _globals['_RECOVERDELETEDUSERREQ']._serialized_end=450
  _globals['_CREATEAPIKEYREQ']._serialized_start=452
  _globals['_CREATEAPIKEYREQ']._serialized_end=483
  _globals['_CREATEAPIKEYRES']._serialized_start=485
  _globals['_CREATEAPIKEYRES']._serialized_end=502
  _globals['_CREATECOMMUNITYREQ']._serialized_start=505
  _globals['_CREATECOMMUNITYREQ']._serialized_end=634
  _globals['_GETCHATSREQ']._serialized_start=636
  _globals['_GETCHATSREQ']._serialized_end=663
  _globals['_GETCHATSRES']._serialized_start=665
  _globals['_GETCHATSRES']._serialized_end=696
  _globals['_ADMIN']._serialized_start=699
  _globals['_ADMIN']._serialized_end=1538
# @@protoc_insertion_point(module_scope)
