# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import auth_pb2 as auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\raccount.proto\x12\x18org.couchers.api.account\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\nauth.proto\"\x99\x02\n\x11GetAccountInfoRes\x12M\n\x0clogin_method\x18\x01 \x01(\x0e\x32\x37.org.couchers.api.account.GetAccountInfoRes.LoginMethod\x12\x14\n\x0chas_password\x18\x02 \x01(\x08\x12\x10\n\x08username\x18\x07 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x18\n\x10profile_complete\x18\x04 \x01(\x08\x12\r\n\x05phone\x18\x08 \x01(\t\x12\x16\n\x0ephone_verified\x18\t \x01(\x08\x12\x10\n\x08timezone\x18\x06 \x01(\t\"+\n\x0bLoginMethod\x12\x0e\n\nMAGIC_LINK\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\"\x87\x01\n\x11\x43hangePasswordReq\x12\x38\n\x0cold_password\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\x12\x38\n\x0cnew_password\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\"Y\n\x0e\x43hangeEmailReq\x12\x34\n\x08password\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\x12\x11\n\tnew_email\x18\x02 \x01(\t\"<\n\x19GetContributorFormInfoRes\x12\x1f\n\x17\x66illed_contributor_form\x18\x01 \x01(\x08\"V\n\x16\x46illContributorFormReq\x12<\n\x10\x63ontributor_form\x18\x01 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\"\x1f\n\x0e\x43hangePhoneReq\x12\r\n\x05phone\x18\x01 \x01(\t\"%\n\x0eVerifyPhoneReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"3\n\x10\x44\x65leteAccountReq\x12\x0f\n\x07\x63onfirm\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t2\xdd\x05\n\x07\x41\x63\x63ount\x12W\n\x0eGetAccountInfo\x12\x16.google.protobuf.Empty\x1a+.org.couchers.api.account.GetAccountInfoRes\"\x00\x12W\n\x0e\x43hangePassword\x12+.org.couchers.api.account.ChangePasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangeEmail\x12(.org.couchers.api.account.ChangeEmailReq\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x16GetContributorFormInfo\x12\x16.google.protobuf.Empty\x1a\x33.org.couchers.api.account.GetContributorFormInfoRes\"\x00\x12\x61\n\x13\x46illContributorForm\x12\x30.org.couchers.api.account.FillContributorFormReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangePhone\x12(.org.couchers.api.account.ChangePhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0bVerifyPhone\x12(.org.couchers.api.account.VerifyPhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\rDeleteAccount\x12*.org.couchers.api.account.DeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['old_password']._loaded_options = None
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['old_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['new_password']._loaded_options = None
  _globals['_CHANGEPASSWORDREQ'].fields_by_name['new_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEEMAILREQ'].fields_by_name['password']._loaded_options = None
  _globals['_CHANGEEMAILREQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._loaded_options = None
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._serialized_options = b'\200\265\030\001'
  _globals['_ACCOUNT']._loaded_options = None
  _globals['_ACCOUNT']._serialized_options = b'\210\265\030\003'
  _globals['_GETACCOUNTINFORES']._serialized_start=136
  _globals['_GETACCOUNTINFORES']._serialized_end=417
  _globals['_GETACCOUNTINFORES_LOGINMETHOD']._serialized_start=374
  _globals['_GETACCOUNTINFORES_LOGINMETHOD']._serialized_end=417
  _globals['_CHANGEPASSWORDREQ']._serialized_start=420
  _globals['_CHANGEPASSWORDREQ']._serialized_end=555
  _globals['_CHANGEEMAILREQ']._serialized_start=557
  _globals['_CHANGEEMAILREQ']._serialized_end=646
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_start=648
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_end=708
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_start=710
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_end=796
  _globals['_CHANGEPHONEREQ']._serialized_start=798
  _globals['_CHANGEPHONEREQ']._serialized_end=829
  _globals['_VERIFYPHONEREQ']._serialized_start=831
  _globals['_VERIFYPHONEREQ']._serialized_end=868
  _globals['_DELETEACCOUNTREQ']._serialized_start=870
  _globals['_DELETEACCOUNTREQ']._serialized_end=921
  _globals['_ACCOUNT']._serialized_start=924
  _globals['_ACCOUNT']._serialized_end=1657
# @@protoc_insertion_point(module_scope)
