# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgis.proto\x12\x11org.couchers.json\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto2\xe3\x02\n\x03GIS\x12P\n\x08GetUsers\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/geojson/users\x12\\\n\x0eGetCommunities\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/geojson/communities\x12R\n\tGetPlaces\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/places\x12R\n\tGetGuides\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/geojson/guides\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GIS']._loaded_options = None
  _globals['_GIS']._serialized_options = b'\210\265\030\003'
  _globals['_GIS'].methods_by_name['GetUsers']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetUsers']._serialized_options = b'\202\323\344\223\002\020\022\016/geojson/users'
  _globals['_GIS'].methods_by_name['GetCommunities']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetCommunities']._serialized_options = b'\202\323\344\223\002\026\022\024/geojson/communities'
  _globals['_GIS'].methods_by_name['GetPlaces']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetPlaces']._serialized_options = b'\202\323\344\223\002\021\022\017/geojson/places'
  _globals['_GIS'].methods_by_name['GetGuides']._loaded_options = None
  _globals['_GIS'].methods_by_name['GetGuides']._serialized_options = b'\202\323\344\223\002\021\022\017/geojson/guides'
  _globals['_GIS']._serialized_start=138
  _globals['_GIS']._serialized_end=493
# @@protoc_insertion_point(module_scope)
