# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: references.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10references.proto\x12\x1borg.couchers.api.references\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\xe8\x01\n\tReference\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x66rom_user_id\x18\x02 \x01(\x03\x12\x12\n\nto_user_id\x18\x03 \x01(\x03\x12\x42\n\x0ereference_type\x18\x04 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x30\n\x0cwritten_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fhost_request_id\x18\x07 \x01(\x03\"\xaf\x01\n\x11ListReferencesReq\x12\x14\n\x0c\x66rom_user_id\x18\x01 \x01(\x04\x12\x12\n\nto_user_id\x18\x02 \x01(\x04\x12I\n\x15reference_type_filter\x18\x03 \x03(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x11\n\tpage_size\x18\x04 \x01(\r\x12\x12\n\npage_token\x18\x05 \x01(\t\"h\n\x11ListReferencesRes\x12:\n\nreferences\x18\x01 \x03(\x0b\x32&.org.couchers.api.references.Reference\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"z\n\x17WriteFriendReferenceReq\x12\x12\n\nto_user_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x14\n\x0cprivate_text\x18\x05 \x01(\t\x12\x17\n\x0fwas_appropriate\x18\x03 \x01(\x08\x12\x0e\n\x06rating\x18\x04 \x01(\x01\"\x84\x01\n\x1cWriteHostRequestReferenceReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x14\n\x0cprivate_text\x18\x05 \x01(\t\x12\x17\n\x0fwas_appropriate\x18\x03 \x01(\x08\x12\x0e\n\x06rating\x18\x04 \x01(\x01\"1\n\x1b\x41vailableWriteReferencesReq\x12\x12\n\nto_user_id\x18\x01 \x01(\x03\"\xac\x01\n\x1b\x41vailableWriteReferenceType\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x42\n\x0ereference_type\x18\x02 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\x12\x30\n\x0ctime_expires\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9f\x01\n\x1b\x41vailableWriteReferencesRes\x12\"\n\x1a\x63\x61n_write_friend_reference\x18\x01 \x01(\x08\x12\\\n\x1a\x61vailable_write_references\x18\x02 \x03(\x0b\x32\x38.org.couchers.api.references.AvailableWriteReferenceType\"w\n\x1fListPendingReferencesToWriteRes\x12T\n\x12pending_references\x18\x01 \x03(\x0b\x32\x38.org.couchers.api.references.AvailableWriteReferenceType*`\n\rReferenceType\x12\x19\n\x15REFERENCE_TYPE_FRIEND\x10\x00\x12\x19\n\x15REFERENCE_TYPE_SURFED\x10\x01\x12\x19\n\x15REFERENCE_TYPE_HOSTED\x10\x02\x32\x8c\x05\n\nReferences\x12r\n\x0eListReferences\x12..org.couchers.api.references.ListReferencesReq\x1a..org.couchers.api.references.ListReferencesRes\"\x00\x12v\n\x14WriteFriendReference\x12\x34.org.couchers.api.references.WriteFriendReferenceReq\x1a&.org.couchers.api.references.Reference\"\x00\x12\x80\x01\n\x19WriteHostRequestReference\x12\x39.org.couchers.api.references.WriteHostRequestReferenceReq\x1a&.org.couchers.api.references.Reference\"\x00\x12\x90\x01\n\x18\x41vailableWriteReferences\x12\x38.org.couchers.api.references.AvailableWriteReferencesReq\x1a\x38.org.couchers.api.references.AvailableWriteReferencesRes\"\x00\x12v\n\x1cListPendingReferencesToWrite\x12\x16.google.protobuf.Empty\x1a<.org.couchers.api.references.ListPendingReferencesToWriteRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'references_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REFERENCES']._loaded_options = None
  _globals['_REFERENCES']._serialized_options = b'\210\265\030\003'
  _globals['_REFERENCETYPE']._serialized_start=1417
  _globals['_REFERENCETYPE']._serialized_end=1513
  _globals['_REFERENCE']._serialized_start=131
  _globals['_REFERENCE']._serialized_end=363
  _globals['_LISTREFERENCESREQ']._serialized_start=366
  _globals['_LISTREFERENCESREQ']._serialized_end=541
  _globals['_LISTREFERENCESRES']._serialized_start=543
  _globals['_LISTREFERENCESRES']._serialized_end=647
  _globals['_WRITEFRIENDREFERENCEREQ']._serialized_start=649
  _globals['_WRITEFRIENDREFERENCEREQ']._serialized_end=771
  _globals['_WRITEHOSTREQUESTREFERENCEREQ']._serialized_start=774
  _globals['_WRITEHOSTREQUESTREFERENCEREQ']._serialized_end=906
  _globals['_AVAILABLEWRITEREFERENCESREQ']._serialized_start=908
  _globals['_AVAILABLEWRITEREFERENCESREQ']._serialized_end=957
  _globals['_AVAILABLEWRITEREFERENCETYPE']._serialized_start=960
  _globals['_AVAILABLEWRITEREFERENCETYPE']._serialized_end=1132
  _globals['_AVAILABLEWRITEREFERENCESRES']._serialized_start=1135
  _globals['_AVAILABLEWRITEREFERENCESRES']._serialized_end=1294
  _globals['_LISTPENDINGREFERENCESTOWRITERES']._serialized_start=1296
  _globals['_LISTPENDINGREFERENCESTOWRITERES']._serialized_end=1415
  _globals['_REFERENCES']._serialized_start=1516
  _globals['_REFERENCES']._serialized_end=2168
# @@protoc_insertion_point(module_scope)
