# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tapi.proto\x12\x15org.couchers.api.core\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\"\'\n\x14SendFriendRequestReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\"\xc4\x01\n\rFriendRequest\x12\x19\n\x11\x66riend_request_id\x18\x01 \x01(\x03\x12G\n\x05state\x18\x02 \x01(\x0e\x32\x38.org.couchers.api.core.FriendRequest.FriendRequestStatus\x12\x0f\n\x07user_id\x18\x03 \x01(\x03\x12\x0c\n\x04sent\x18\x04 \x01(\x08\"0\n\x13\x46riendRequestStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x01\"D\n\x17RespondFriendRequestReq\x12\x19\n\x11\x66riend_request_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\"3\n\x16\x43\x61ncelFriendRequestReq\x12\x19\n\x11\x66riend_request_id\x18\x01 \x01(\x03\"\x83\x01\n\x15ListFriendRequestsRes\x12\x32\n\x04sent\x18\x01 \x03(\x0b\x32$.org.couchers.api.core.FriendRequest\x12\x36\n\x08received\x18\x02 \x03(\x0b\x32$.org.couchers.api.core.FriendRequest\"\"\n\x0eListFriendsRes\x12\x10\n\x08user_ids\x18\x01 \x03(\x03\"\'\n\x14ListMutualFriendsReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\"S\n\x14ListMutualFriendsRes\x12;\n\x0emutual_friends\x18\x01 \x03(\x0b\x32#.org.couchers.api.core.MutualFriend\"\t\n\x07PingReq\"\xcc\x01\n\x07PingRes\x12)\n\x04user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x1c\n\x14unseen_message_count\x18\x02 \x01(\r\x12&\n\x1eunseen_sent_host_request_count\x18\x05 \x01(\r\x12*\n\"unseen_received_host_request_count\x18\x06 \x01(\r\x12$\n\x1cpending_friend_request_count\x18\x04 \x01(\r\"?\n\x0cMutualFriend\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xc6\x01\n\x0fLanguageAbility\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12?\n\x07\x66luency\x18\x02 \x01(\x0e\x32..org.couchers.api.core.LanguageAbility.Fluency\"d\n\x07\x46luency\x12\x13\n\x0f\x46LUENCY_UNKNOWN\x10\x00\x12\x14\n\x10\x46LUENCY_BEGINNER\x10\x01\x12\x1a\n\x16\x46LUENCY_CONVERSATIONAL\x10\x02\x12\x12\n\x0e\x46LUENCY_FLUENT\x10\x03\"5\n\x13NullableUInt32Value\x12\x0f\n\x07is_null\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\r\"3\n\x11NullableBoolValue\x12\x0f\n\x07is_null\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x08\"5\n\x13NullableStringValue\x12\x0f\n\x07is_null\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"\x95\x11\n\x04User\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\x10\n\x08hometown\x18\x64 \x01(\t\x12\x10\n\x08timezone\x18z \x01(\t\x12\x0b\n\x03lat\x18! \x01(\x01\x12\x0b\n\x03lng\x18\" \x01(\x01\x12\x0e\n\x06radius\x18# \x01(\x01\x12\x14\n\x0cverification\x18\x05 \x01(\x01\x12\x1a\n\x12\x63ommunity_standing\x18\x06 \x01(\x01\x12\x16\n\x0enum_references\x18\x07 \x01(\r\x12\x0e\n\x06gender\x18\x08 \x01(\t\x12\x10\n\x08pronouns\x18\x65 \x01(\t\x12\x0b\n\x03\x61ge\x18\t \x01(\r\x12*\n\x06joined\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_active\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\r \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\x66 \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x12\n\noccupation\x18\x0e \x01(\t\x12\x11\n\teducation\x18g \x01(\t\x12\x10\n\x08\x61\x62out_me\x18\x0f \x01(\t\x12\x12\n\nmy_travels\x18h \x01(\t\x12\x15\n\rthings_i_like\x18i \x01(\t\x12\x13\n\x0b\x61\x62out_place\x18\x10 \x01(\t\x12\x17\n\x0fregions_visited\x18( \x03(\t\x12\x15\n\rregions_lived\x18) \x03(\t\x12\x1e\n\x16\x61\x64\x64itional_information\x18j \x01(\t\x12=\n\x07\x66riends\x18\x14 \x01(\x0e\x32,.org.couchers.api.core.User.FriendshipStatus\x12\x44\n\x16pending_friend_request\x18$ \x01(\x0b\x32$.org.couchers.api.core.FriendRequest\x12\x30\n\nmax_guests\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\x0blast_minute\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_pets\x18k \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_pets\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\x0bpet_details\x18l \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08has_kids\x18m \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_kids\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\x0bkid_details\x18n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0ehas_housemates\x18o \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x11housemate_details\x18p \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x15wheelchair_accessible\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0fsmoking_allowed\x18\x1c \x01(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12\x32\n\x0esmokes_at_home\x18q \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x64rinking_allowed\x18r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x64rinks_at_home\x18s \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x0fother_host_info\x18t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12H\n\x14sleeping_arrangement\x18u \x01(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x36\n\x10sleeping_details\x18v \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x61rea\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bhouse_rules\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x07parking\x18w \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x0fparking_details\x18x \x01(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12.\n\ncamping_ok\x18y \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x12\n\navatar_url\x18  \x01(\t\x12\x42\n\x12language_abilities\x18% \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\"E\n\x10\x46riendshipStatus\x12\x0f\n\x0bNOT_FRIENDS\x10\x00\x12\x0b\n\x07\x46RIENDS\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x06\n\x02NA\x10\x03\"\x1a\n\nGetUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"$\n\x13RepeatedStringValue\x12\r\n\x05value\x18\x02 \x03(\t\"U\n\x1cRepeatedLanguageAbilityValue\x12\x35\n\x05value\x18\x01 \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\"\xa7\x15\n\x10UpdateProfileReq\x12*\n\x04name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ity\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\x08hometown\x18\x64 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12)\n\x03lat\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12)\n\x03lng\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06radius\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12>\n\navatar_key\x18\x19 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12<\n\x08pronouns\x18\x65 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12>\n\noccupation\x18\x04 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12=\n\teducation\x18\x66 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12<\n\x08\x61\x62out_me\x18\x05 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12>\n\nmy_travels\x18g \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12\x41\n\rthings_i_like\x18h \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12?\n\x0b\x61\x62out_place\x18\x06 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12<\n\x0ehosting_status\x18\x08 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18i \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x43\n\x0fregions_visited\x18\x1e \x01(\x0b\x32*.org.couchers.api.core.RepeatedStringValue\x12\x41\n\rregions_lived\x18\x1f \x01(\x0b\x32*.org.couchers.api.core.RepeatedStringValue\x12J\n\x16\x61\x64\x64itional_information\x18j \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12>\n\nmax_guests\x18\x0c \x01(\x0b\x32*.org.couchers.api.core.NullableUInt32Value\x12=\n\x0blast_minute\x18\x0e \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12:\n\x08has_pets\x18k \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12>\n\x0c\x61\x63\x63\x65pts_pets\x18\x0f \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12?\n\x0bpet_details\x18l \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12:\n\x08has_kids\x18m \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12>\n\x0c\x61\x63\x63\x65pts_kids\x18\x10 \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12?\n\x0bkid_details\x18n \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12@\n\x0ehas_housemates\x18o \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12\x45\n\x11housemate_details\x18p \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12G\n\x15wheelchair_accessible\x18\x11 \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12?\n\x0fsmoking_allowed\x18\x12 \x01(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12@\n\x0esmokes_at_home\x18q \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12\x42\n\x10\x64rinking_allowed\x18r \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12@\n\x0e\x64rinks_at_home\x18s \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12\x43\n\x0fother_host_info\x18t \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12H\n\x14sleeping_arrangement\x18u \x01(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x44\n\x10sleeping_details\x18v \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12\x38\n\x04\x61rea\x18\x14 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12?\n\x0bhouse_rules\x18\x15 \x01(\x0b\x32*.org.couchers.api.core.NullableStringValue\x12\x39\n\x07parking\x18w \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12>\n\x0fparking_details\x18x \x01(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12<\n\ncamping_ok\x18y \x01(\x0b\x32(.org.couchers.api.core.NullableBoolValue\x12O\n\x12language_abilities\x18\x1a \x01(\x0b\x32\x33.org.couchers.api.core.RepeatedLanguageAbilityValue\"X\n\x16InitiateMediaUploadRes\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12*\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*\xa0\x01\n\rHostingStatus\x12\x1e\n\x1aHOSTING_STATUS_UNSPECIFIED\x10\x00\x12\x1a\n\x16HOSTING_STATUS_UNKNOWN\x10\x01\x12\x1b\n\x17HOSTING_STATUS_CAN_HOST\x10\x02\x12\x18\n\x14HOSTING_STATUS_MAYBE\x10\x03\x12\x1c\n\x18HOSTING_STATUS_CANT_HOST\x10\x04*\xb8\x01\n\x0cMeetupStatus\x12\x1d\n\x19MEETUP_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15MEETUP_STATUS_UNKNOWN\x10\x01\x12!\n\x1dMEETUP_STATUS_WANTS_TO_MEETUP\x10\x02\x12 \n\x1cMEETUP_STATUS_OPEN_TO_MEETUP\x10\x03\x12)\n%MEETUP_STATUS_DOES_NOT_WANT_TO_MEETUP\x10\x04*\xbf\x01\n\x0fSmokingLocation\x12 \n\x1cSMOKING_LOCATION_UNSPECIFIED\x10\x00\x12\x1c\n\x18SMOKING_LOCATION_UNKNOWN\x10\x01\x12\x18\n\x14SMOKING_LOCATION_YES\x10\x02\x12\x1b\n\x17SMOKING_LOCATION_WINDOW\x10\x03\x12\x1c\n\x18SMOKING_LOCATION_OUTSIDE\x10\x04\x12\x17\n\x13SMOKING_LOCATION_NO\x10\x05*\xed\x01\n\x13SleepingArrangement\x12$\n SLEEPING_ARRANGEMENT_UNSPECIFIED\x10\x00\x12 \n\x1cSLEEPING_ARRANGEMENT_UNKNOWN\x10\x01\x12 \n\x1cSLEEPING_ARRANGEMENT_PRIVATE\x10\x02\x12\x1f\n\x1bSLEEPING_ARRANGEMENT_COMMON\x10\x03\x12$\n SLEEPING_ARRANGEMENT_SHARED_ROOM\x10\x04\x12%\n!SLEEPING_ARRANGEMENT_SHARED_SPACE\x10\x05*\xd4\x01\n\x0eParkingDetails\x12\x1f\n\x1bPARKING_DETAILS_UNSPECIFIED\x10\x00\x12\x1b\n\x17PARKING_DETAILS_UNKNOWN\x10\x01\x12\x1f\n\x1bPARKING_DETAILS_FREE_ONSITE\x10\x02\x12 \n\x1cPARKING_DETAILS_FREE_OFFSITE\x10\x03\x12\x1f\n\x1bPARKING_DETAILS_PAID_ONSITE\x10\x04\x12 \n\x1cPARKING_DETAILS_PAID_OFFSITE\x10\x05\x32\x89\x07\n\x03\x41PI\x12H\n\x04Ping\x12\x1e.org.couchers.api.core.PingReq\x1a\x1e.org.couchers.api.core.PingRes\"\x00\x12K\n\x07GetUser\x12!.org.couchers.api.core.GetUserReq\x1a\x1b.org.couchers.api.core.User\"\x00\x12R\n\rUpdateProfile\x12\'.org.couchers.api.core.UpdateProfileReq\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x11SendFriendRequest\x12+.org.couchers.api.core.SendFriendRequestReq\x1a\x16.google.protobuf.Empty\x12Z\n\x12ListFriendRequests\x12\x16.google.protobuf.Empty\x1a,.org.couchers.api.core.ListFriendRequestsRes\x12L\n\x0bListFriends\x12\x16.google.protobuf.Empty\x1a%.org.couchers.api.core.ListFriendsRes\x12o\n\x11ListMutualFriends\x12+.org.couchers.api.core.ListMutualFriendsReq\x1a+.org.couchers.api.core.ListMutualFriendsRes\"\x00\x12^\n\x14RespondFriendRequest\x12..org.couchers.api.core.RespondFriendRequestReq\x1a\x16.google.protobuf.Empty\x12\\\n\x13\x43\x61ncelFriendRequest\x12-.org.couchers.api.core.CancelFriendRequestReq\x1a\x16.google.protobuf.Empty\x12^\n\x13InitiateMediaUpload\x12\x16.google.protobuf.Empty\x1a-.org.couchers.api.core.InitiateMediaUploadRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_API']._loaded_options = None
  _globals['_API']._serialized_options = b'\210\265\030\003'
  _globals['_HOSTINGSTATUS']._serialized_start=6629
  _globals['_HOSTINGSTATUS']._serialized_end=6789
  _globals['_MEETUPSTATUS']._serialized_start=6792
  _globals['_MEETUPSTATUS']._serialized_end=6976
  _globals['_SMOKINGLOCATION']._serialized_start=6979
  _globals['_SMOKINGLOCATION']._serialized_end=7170
  _globals['_SLEEPINGARRANGEMENT']._serialized_start=7173
  _globals['_SLEEPINGARRANGEMENT']._serialized_end=7410
  _globals['_PARKINGDETAILS']._serialized_start=7413
  _globals['_PARKINGDETAILS']._serialized_end=7625
  _globals['_SENDFRIENDREQUESTREQ']._serialized_start=149
  _globals['_SENDFRIENDREQUESTREQ']._serialized_end=188
  _globals['_FRIENDREQUEST']._serialized_start=191
  _globals['_FRIENDREQUEST']._serialized_end=387
  _globals['_FRIENDREQUEST_FRIENDREQUESTSTATUS']._serialized_start=339
  _globals['_FRIENDREQUEST_FRIENDREQUESTSTATUS']._serialized_end=387
  _globals['_RESPONDFRIENDREQUESTREQ']._serialized_start=389
  _globals['_RESPONDFRIENDREQUESTREQ']._serialized_end=457
  _globals['_CANCELFRIENDREQUESTREQ']._serialized_start=459
  _globals['_CANCELFRIENDREQUESTREQ']._serialized_end=510
  _globals['_LISTFRIENDREQUESTSRES']._serialized_start=513
  _globals['_LISTFRIENDREQUESTSRES']._serialized_end=644
  _globals['_LISTFRIENDSRES']._serialized_start=646
  _globals['_LISTFRIENDSRES']._serialized_end=680
  _globals['_LISTMUTUALFRIENDSREQ']._serialized_start=682
  _globals['_LISTMUTUALFRIENDSREQ']._serialized_end=721
  _globals['_LISTMUTUALFRIENDSRES']._serialized_start=723
  _globals['_LISTMUTUALFRIENDSRES']._serialized_end=806
  _globals['_PINGREQ']._serialized_start=808
  _globals['_PINGREQ']._serialized_end=817
  _globals['_PINGRES']._serialized_start=820
  _globals['_PINGRES']._serialized_end=1024
  _globals['_MUTUALFRIEND']._serialized_start=1026
  _globals['_MUTUALFRIEND']._serialized_end=1089
  _globals['_LANGUAGEABILITY']._serialized_start=1092
  _globals['_LANGUAGEABILITY']._serialized_end=1290
  _globals['_LANGUAGEABILITY_FLUENCY']._serialized_start=1190
  _globals['_LANGUAGEABILITY_FLUENCY']._serialized_end=1290
  _globals['_NULLABLEUINT32VALUE']._serialized_start=1292
  _globals['_NULLABLEUINT32VALUE']._serialized_end=1345
  _globals['_NULLABLEBOOLVALUE']._serialized_start=1347
  _globals['_NULLABLEBOOLVALUE']._serialized_end=1398
  _globals['_NULLABLESTRINGVALUE']._serialized_start=1400
  _globals['_NULLABLESTRINGVALUE']._serialized_end=1453
  _globals['_USER']._serialized_start=1456
  _globals['_USER']._serialized_end=3653
  _globals['_USER_FRIENDSHIPSTATUS']._serialized_start=3584
  _globals['_USER_FRIENDSHIPSTATUS']._serialized_end=3653
  _globals['_GETUSERREQ']._serialized_start=3655
  _globals['_GETUSERREQ']._serialized_end=3681
  _globals['_REPEATEDSTRINGVALUE']._serialized_start=3683
  _globals['_REPEATEDSTRINGVALUE']._serialized_end=3719
  _globals['_REPEATEDLANGUAGEABILITYVALUE']._serialized_start=3721
  _globals['_REPEATEDLANGUAGEABILITYVALUE']._serialized_end=3806
  _globals['_UPDATEPROFILEREQ']._serialized_start=3809
  _globals['_UPDATEPROFILEREQ']._serialized_end=6536
  _globals['_INITIATEMEDIAUPLOADRES']._serialized_start=6538
  _globals['_INITIATEMEDIAUPLOADRES']._serialized_end=6626
  _globals['_API']._serialized_start=7628
  _globals['_API']._serialized_end=8533
# @@protoc_insertion_point(module_scope)
