# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import notifications_pb2 as notifications__pb2


class NotificationsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetNotificationSettings = channel.unary_unary(
                '/org.couchers.notifications.Notifications/GetNotificationSettings',
                request_serializer=notifications__pb2.GetNotificationSettingsReq.SerializeToString,
                response_deserializer=notifications__pb2.GetNotificationSettingsRes.FromString,
                )
        self.SetNotificationSettings = channel.unary_unary(
                '/org.couchers.notifications.Notifications/SetNotificationSettings',
                request_serializer=notifications__pb2.SetNotificationSettingsReq.SerializeToString,
                response_deserializer=notifications__pb2.SetNotificationSettingsRes.FromString,
                )


class NotificationsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetNotificationSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNotificationSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetNotificationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotificationSettings,
                    request_deserializer=notifications__pb2.GetNotificationSettingsReq.FromString,
                    response_serializer=notifications__pb2.GetNotificationSettingsRes.SerializeToString,
            ),
            'SetNotificationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNotificationSettings,
                    request_deserializer=notifications__pb2.SetNotificationSettingsReq.FromString,
                    response_serializer=notifications__pb2.SetNotificationSettingsRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.notifications.Notifications', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Notifications(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetNotificationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/GetNotificationSettings',
            notifications__pb2.GetNotificationSettingsReq.SerializeToString,
            notifications__pb2.GetNotificationSettingsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNotificationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/SetNotificationSettings',
            notifications__pb2.SetNotificationSettingsReq.SerializeToString,
            notifications__pb2.SetNotificationSettingsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
