# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jail.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\njail.proto\x12\x11org.couchers.jail\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"\xa8\x01\n\x0bJailInfoRes\x12\x0e\n\x06jailed\x18\x01 \x01(\x08\x12\x1c\n\x14has_not_accepted_tos\x18\x02 \x01(\x08\x12\x1e\n\x16has_not_added_location\x18\x03 \x01(\x08\x12-\n%has_not_accepted_community_guidelines\x18\x04 \x01(\x08\x12\x1c\n\x14has_not_set_password\x18\x05 \x01(\x08\"\x1e\n\x0c\x41\x63\x63\x65ptTOSReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\"H\n\x0eSetLocationReq\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06radius\x18\x04 \x01(\x01\".\n\x1c\x41\x63\x63\x65ptCommunityGuidelinesReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\",\n\x0eSetPasswordReq\x12\x1a\n\x0cnew_password\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x32\xba\x03\n\x04Jail\x12\x44\n\x08JailInfo\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12N\n\tAcceptTOS\x12\x1f.org.couchers.jail.AcceptTOSReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12R\n\x0bSetLocation\x12!.org.couchers.jail.SetLocationReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12n\n\x19\x41\x63\x63\x65ptCommunityGuidelines\x12/.org.couchers.jail.AcceptCommunityGuidelinesReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12R\n\x0bSetPassword\x12!.org.couchers.jail.SetPasswordReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x1a\x04\x88\xb5\x18\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jail_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SETPASSWORDREQ'].fields_by_name['new_password']._loaded_options = None
  _globals['_SETPASSWORDREQ'].fields_by_name['new_password']._serialized_options = b'\200\265\030\001'
  _globals['_JAIL']._loaded_options = None
  _globals['_JAIL']._serialized_options = b'\210\265\030\002'
  _globals['_JAILINFORES']._serialized_start=82
  _globals['_JAILINFORES']._serialized_end=250
  _globals['_ACCEPTTOSREQ']._serialized_start=252
  _globals['_ACCEPTTOSREQ']._serialized_end=282
  _globals['_SETLOCATIONREQ']._serialized_start=284
  _globals['_SETLOCATIONREQ']._serialized_end=356
  _globals['_ACCEPTCOMMUNITYGUIDELINESREQ']._serialized_start=358
  _globals['_ACCEPTCOMMUNITYGUIDELINESREQ']._serialized_end=404
  _globals['_SETPASSWORDREQ']._serialized_start=406
  _globals['_SETPASSWORDREQ']._serialized_end=450
  _globals['_JAIL']._serialized_start=453
  _globals['_JAIL']._serialized_end=895
# @@protoc_insertion_point(module_scope)
