# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import admin_pb2 as admin__pb2
from . import communities_pb2 as communities__pb2


class AdminStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserDetails = channel.unary_unary(
                '/org.couchers.admin.Admin/GetUserDetails',
                request_serializer=admin__pb2.GetUserDetailsReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.ChangeUserGender = channel.unary_unary(
                '/org.couchers.admin.Admin/ChangeUserGender',
                request_serializer=admin__pb2.ChangeUserGenderReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.ChangeUserBirthdate = channel.unary_unary(
                '/org.couchers.admin.Admin/ChangeUserBirthdate',
                request_serializer=admin__pb2.ChangeUserBirthdateReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.BanUser = channel.unary_unary(
                '/org.couchers.admin.Admin/BanUser',
                request_serializer=admin__pb2.BanUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/org.couchers.admin.Admin/DeleteUser',
                request_serializer=admin__pb2.DeleteUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.RecoverDeletedUser = channel.unary_unary(
                '/org.couchers.admin.Admin/RecoverDeletedUser',
                request_serializer=admin__pb2.RecoverDeletedUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.CreateApiKey = channel.unary_unary(
                '/org.couchers.admin.Admin/CreateApiKey',
                request_serializer=admin__pb2.CreateApiKeyReq.SerializeToString,
                response_deserializer=admin__pb2.CreateApiKeyRes.FromString,
                )
        self.CreateCommunity = channel.unary_unary(
                '/org.couchers.admin.Admin/CreateCommunity',
                request_serializer=admin__pb2.CreateCommunityReq.SerializeToString,
                response_deserializer=communities__pb2.Community.FromString,
                )
        self.GetChats = channel.unary_unary(
                '/org.couchers.admin.Admin/GetChats',
                request_serializer=admin__pb2.GetChatsReq.SerializeToString,
                response_deserializer=admin__pb2.GetChatsRes.FromString,
                )


class AdminServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeUserGender(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeUserBirthdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BanUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecoverDeletedUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApiKey(self, request, context):
        """Create an API key for a user. For security, we don't return the API key to the admin calling this API, rather
        it's sent to the user in an email
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCommunity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUserDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserDetails,
                    request_deserializer=admin__pb2.GetUserDetailsReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'ChangeUserGender': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeUserGender,
                    request_deserializer=admin__pb2.ChangeUserGenderReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'ChangeUserBirthdate': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeUserBirthdate,
                    request_deserializer=admin__pb2.ChangeUserBirthdateReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'BanUser': grpc.unary_unary_rpc_method_handler(
                    servicer.BanUser,
                    request_deserializer=admin__pb2.BanUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=admin__pb2.DeleteUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'RecoverDeletedUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RecoverDeletedUser,
                    request_deserializer=admin__pb2.RecoverDeletedUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'CreateApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApiKey,
                    request_deserializer=admin__pb2.CreateApiKeyReq.FromString,
                    response_serializer=admin__pb2.CreateApiKeyRes.SerializeToString,
            ),
            'CreateCommunity': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCommunity,
                    request_deserializer=admin__pb2.CreateCommunityReq.FromString,
                    response_serializer=communities__pb2.Community.SerializeToString,
            ),
            'GetChats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChats,
                    request_deserializer=admin__pb2.GetChatsReq.FromString,
                    response_serializer=admin__pb2.GetChatsRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.admin.Admin', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Admin(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetUserDetails',
            admin__pb2.GetUserDetailsReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeUserGender(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ChangeUserGender',
            admin__pb2.ChangeUserGenderReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeUserBirthdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ChangeUserBirthdate',
            admin__pb2.ChangeUserBirthdateReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BanUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/BanUser',
            admin__pb2.BanUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/DeleteUser',
            admin__pb2.DeleteUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecoverDeletedUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/RecoverDeletedUser',
            admin__pb2.RecoverDeletedUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/CreateApiKey',
            admin__pb2.CreateApiKeyReq.SerializeToString,
            admin__pb2.CreateApiKeyRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCommunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/CreateCommunity',
            admin__pb2.CreateCommunityReq.SerializeToString,
            communities__pb2.Community.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetChats',
            admin__pb2.GetChatsReq.SerializeToString,
            admin__pb2.GetChatsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
